@@ -512,11 +512,13 @@ dupnstr(const char *s, int n)
 char *
 dupstr_utf8(const char * s)
 {
-  int m = 2, result=0;
-  char *i_buf = NULL, * o_buf = NULL, *o = NULL;
+  int result=0;
+  char *o = NULL;
+#ifdef HAVE_ICONV_H
+  int m = 2;
+  char *i_buf = NULL, * o_buf = NULL;
   size_t i_bytes, o_bytes, o_len;
 
-#ifdef HAVE_ICONV_H
   errno=0;
   if (command.cd) {
     do {
