@@ -214,7 +214,7 @@ xwindow_updated_background(Display * display, Window root, Atom id)
 
   if (!(display && root)) return 0;
 
-  if(id==None) id=XInternAtom(display,"_XROOTMAP_ID", True);
+  if(id==None) id=XInternAtom(display,"_XROOTPMAP_ID", True);
   if(id!=None &&
      XGetWindowProperty(display, root, id, 0, 1, False, XA_PIXMAP,
 			&act_type, &act_format, &nitems, &bytes_after,
@@ -516,10 +516,12 @@ xwindow_resize_window(Display * display, Window window, cfgfile_item * item,
 	    result=1;
 	  }
 	}
-      }
+      } else
+	if (!force_update) result=1;
   return result;
 }
 
+#ifdef WM_DETECTION_OLD_STYLE
 /*----------------------------------------------------------------------------*/
 /* Here is a function that recursively calls itself (up to a limit) to find 
    the window ID of the KDE desktop to draw on. This is the hierarchy we're 
@@ -649,6 +651,7 @@ xwindow_get_nautilus_desktop(Display *display, int screen, Window window,
   }
   return winreturn;
 }
+#endif	/* WM_DETECTION_OLD_STYLE */
 
 /*----------------------------------------------------------------------------*/
 /* Returns the root window, or the fake root window depending on
@@ -657,6 +660,7 @@ xwindow_get_nautilus_desktop(Display *display, int screen, Window window,
 Window
 xwindow_get_root_window(Display * display, int scr)
 {
+#ifdef WM_DETECTION_OLD_STYLE
   int i;
   unsigned long dummy;
   Window rootReturn, parentReturn, *children;
@@ -704,11 +708,28 @@ xwindow_get_root_window(Display * display, int scr)
 	result = xwindow_get_kde_desktop(display, scr, children[i],
 					 _NET_WM_WINDOW_TYPE,
 					 "_NET_WM_WINDOW_TYPE_DESKTOP",
-					 0);
+					 0);    
     }
     XFree((char *) children);
   }
+
   return (result)?result:root;
+#else
+  uint window = 0;
+  char * root_env;
+  XWindowAttributes xattr;
+
+  /* Try reading the ADESKLETS_ROOT environment variable to identify the root */
+  if ((root_env=getenv("ADESKLETS_ROOT")) &&
+      sscanf(root_env,"%x", &window)==1)
+    if (XGetWindowAttributes(display, (Window)window, &xattr)==0) {
+      debug("Invalid 0x%x Windows given as root!", window);
+      window=0;
+    }
+  
+  /* Use the specified window as root, or the real root otherwise */
+  return (window)?(Window)window:RootWindow(display, scr);
+#endif /* WM_DETECTION_OLD_STYLE */
 }
 
 #endif /* X_MISSING_DISPLAY , far, far above! */
